==> drools-compiler-4.0.7-sources.jar: org/drools/lang/descr/GlobalDescr.java <==
/*
 * Copyright 2006 JBoss Inc
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.drools.lang.descr;

/**
 * A descriptor class for globals.
 * 
 * @author etirelli
 */
public class GlobalDescr extends BaseDescr {

    private static final long serialVersionUID = 400L;

    private String            identifier;
    private String            type;

    public GlobalDescr() {
        this( null,
              null );
    }

    public GlobalDescr(final String identifier,
                       final String type) {
        this.identifier = identifier;
        this.type = type;
    }

    /**
     * @return the identifier
     */
    public String getIdentifier() {
        return this.identifier;
    }

    /**
     * @param identifier the identifier to set
     */
    public void setIdentifier(final String identifier) {
        this.identifier = identifier;
    }

    /**
     * @return the type
     */
    public String getType() {
        return this.type;
    }

    /**
     * @param type the type to set
     */
    public void setType(final String type) {
        this.type = type;
    }

}

==> drools-compiler-5.1.1-sources.jar: org/drools/lang/descr/GlobalDescr.java <==
/*
 * Copyright 2006 JBoss Inc
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.drools.lang.descr;

/**
 * A descriptor class for globals.
 * 
 * @author etirelli
 */
public class GlobalDescr extends BaseDescr {

    private static final long serialVersionUID = 510l;

    private String            identifier;
    private String            type;

    public GlobalDescr() {
        this( null,
              null );
    }

    public GlobalDescr(final String identifier,
                       final String type) {
        this.identifier = identifier;
        this.type = type;
    }

    /**
     * @return the identifier
     */
    public String getIdentifier() {
        return this.identifier;
    }

    /**
     * @param identifier the identifier to set
     */
    public void setIdentifier(final String identifier) {
        this.identifier = identifier;
    }

    /**
     * @return the type
     */
    public String getType() {
        return this.type;
    }

    /**
     * @param type the type to set
     */
    public void setType(final String type) {
        this.type = type;
    }

}
